@@ -1,7 +1,7 @@
 from Crypto.Util.number import long_to_bytes
 from factordb.factordb import FactorDB
 
-__all__ = ['factorDB_RSA']
+#__all__ = ['factorDB_RSA']
 
 #Prints the flag if the factorisation of the modulus is available on factorDB, fefault public exponent value is 65537
 
